function [index errorDescriptor] = challengeViaPoint(preSegIndex, challengedIndex, postSegIndex, modules, globalTraj,varargin)
%% parsing inputs
if isempty(varargin)
    options = check_options();
else
    options = check_options(varargin{1}); % Checking the given options, and add ones are not defined.
end
try
    %% check segment 1
    preSeg1{1}=globalTraj(preSegIndex:challengedIndex,:)';
    
    offset1=preSeg1{1}(1:2,end);
    preSeg1{1}(1:2,:)=preSeg1{1}(1:2,:)-repmat(offset1,1,size(preSeg1{1},2));
    startP = repmat(preSeg1{1}(1:2,1),1,length(modules.shapes))';
    [preSeg1_d1 preSeg1_r1 fitnessValue_preSeg1 MSE_preSeg1 log1]=checkTrajectorieSegments(modules,preSeg1,startP);
    
    [~,I_seg1]=min(cell2mat(MSE_preSeg1));
    %[~,I_seg1]=max(cell2mat(fitnessValue_preSeg1));
    g1 = (preSeg1_r1{I_seg1}(1:2,:)+repmat(offset1,1,size(preSeg1_r1{I_seg1},2)));
    gd1 = (preSeg1_d1{I_seg1}(1:2,:)+repmat(offset1,1,size(preSeg1_d1{I_seg1},2)));
    errorVector1 = log1.errorVector{I_seg1};
    
    %% check segment 2
    preSeg2{1}=globalTraj((challengedIndex+1):postSegIndex,:)';
    offset2=preSeg2{1}(1:2,end);
    preSeg2{1}(1:2,:)=preSeg2{1}(1:2,:)-repmat(offset2,1,size(preSeg2{1},2));
    startP = repmat(preSeg2{1}(1:2,1),1,length(modules.shapes))';
    [preSeg2_d1 preSeg2_r1 fitnessValue_preSeg2 MSE_preSeg2 log2]=checkTrajectorieSegments(modules,preSeg2,startP);
    
    [~,I_seg2]=min(cell2mat(MSE_preSeg2));
    %[~,I_seg2]=max(cell2mat(fitnessValue_preSeg2));
    g2 = (preSeg2_r1{I_seg2}(1:2,:)+repmat(offset2,1,size(preSeg2_r1{I_seg2},2)));
    gd2 = (preSeg2_d1{I_seg2}(1:2,:)+repmat(offset2,1,size(preSeg2_d1{I_seg2},2)));
    errorVector2 = log2.errorVector{I_seg2};
    
    %% check segment 3
    preSeg3{1}=globalTraj(preSegIndex:postSegIndex,:)';
    offset3=preSeg3{1}(1:2,end);
    preSeg3{1}(1:2,:)=preSeg3{1}(1:2,:)-repmat(offset3,1,size(preSeg3{1},2));
    startP = repmat(preSeg3{1}(1:2,1),1,length(modules.shapes))';
    [preSeg3_d1 preSeg3_r1 fitnessValue_preSeg3 MSE_preSeg3 log3]=checkTrajectorieSegments(modules,preSeg3,startP);
    
    [~,I_seg3]=min(cell2mat(MSE_preSeg3));
    %[~,I_seg3]=max(cell2mat(fitnessValue_preSeg3));
    g3 = (preSeg3_r1{I_seg3}(1:2,:)+repmat(offset3,1,size(preSeg3_r1{I_seg3},2)));
    gd3 = (preSeg3_d1{I_seg3}(1:2,:)+repmat(offset3,1,size(preSeg3_d1{I_seg3},2)));
    errorVector3 = log3.errorVector{I_seg3};
    
    %% concatinate segments for global perfomence measurement
    
    gAll = [g1 g2];
    gdAll = [gd1 gd2];
    %% MSE
    LeftError = trajectoryMeasureMSE(g1,gd1);
    RightError = trajectoryMeasureMSE(g2,gd2);
    LeftRightError=trajectoryMeasureMSE(gAll,gdAll);
    ChallengerError = trajectoryMeasureMSE(g3,gd3);
    LEstd =  std(LeftError);
    REstd = std(RightError);
    LREstd = std(LeftRightError);
    Chalstd = std(ChallengerError);
    
    errorDescriptor.seg1_var =LEstd;
    errorDescriptor.seg2_var = REstd;
    errorDescriptor.seg12_var = LREstd;
    errorDescriptor.seg3_var = Chalstd;
    
    errorDescriptor.seg1_err = max(LeftError);
    errorDescriptor.seg2_err = max(RightError);
    errorDescriptor.seg12_err = min([max(LeftError) max(RightError)]);%max(LeftRightError);
    errorDescriptor.seg3_err = max(ChallengerError);
    
    %% do some logging
    errorDescriptor.log.ChallengerError=ChallengerError;
    errorDescriptor.log.LeftRightError=LeftRightError;
    errorDescriptor.log.RightError=RightError;
    errorDescriptor.log.LeftError=LeftError;
    errorDescriptor.log.VectorError12 = [errorVector1 errorVector2];
    errorDescriptor.log.VectorError3 = errorVector3;
    errorDescriptor.log.trajectory3.repro = g3;
    errorDescriptor.log.trajectory3.demo = gd3;
    errorDescriptor.log.trajectory12.repro = gAll;
    errorDescriptor.log.trajectory12.demo = gdAll;
    
    %% Fitness VALUE
    errorDescriptor.seg1_fit = goodnessOfFitStatisticR2(g1,gd1);
    errorDescriptor.seg2_fit = goodnessOfFitStatisticR2(g2,gd2);
    errorDescriptor.seg12_fit =goodnessOfFitStatisticR2(gAll,gdAll);
    errorDescriptor.seg3_fit = goodnessOfFitStatisticR2(g3,gd3);
    
    %% check for intersections of the primitive
    [boolvia] = getRobustIntersections(preSeg3_d1,preSeg3_r1,I_seg3,options.mVmin);
    
    %keyboard
    
    if  boolvia && errorDescriptor.seg12_err < errorDescriptor.seg3_err || log3.boxCriteria(I_seg3)
        % challenge unsuccessfull
        index = challengedIndex;
        
    else
        % challenge successfull
        index = -1;
    end
catch ME
    %   ME
    
    index = -1;
    errorDescriptor=[];
end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function options = check_options(varargin)
if ~isempty(varargin)
    options = varargin{1};
else
    options.mVmin=0.02; %to create the variable
end

if ~isfield(options,'mVmin') % integration time step
    options.mVmin = 0.02;
end
if ~isfield(options,'mVmax') % maximum number of iterations
    options.mVmax = 1000;
end


end