function [extrema fig]= detectExtrema(demos, fig)
%DETECTMAXIMA   detect extrema in a descrete trajectorie
%   DETECTMAXIMA(demos, fig) returns
%
%   OUTPUT:
%       - EXTREMA same size as demos and gives in each cell a vector of the
%       indeces indicating the extrema in the trajectorie.
%   INPUT:
%       - DEMOS cell array of set s of 2D trajectories (demos{i}(1:2,:))
%       - FIG if fig is not an argument of the function a new figure will
%       be created to show the extrema.

color={'b+', 'k+', 'r+', 'g+','y+','m+'};
if ~exist('fig','var') || isempty(fig)
    fig= figure; box on; hold on; grid on;
    xlabel('x (mm)');
    ylabel('y (mm)');
    for it=1:length(demos)
        
        pos=demos{it}(1:2,:)';
        plot(pos(:,1),pos(:,2),color{it})
    end
end
extrema=cell(size(demos));
if length(demos)>1
    for it=1:length(demos)
        
        pos=demos{it}(1:2,:);
        
        % approximate derivatives
        dev_pos= diff(pos,1,2);
        % smooth data to prevent multiple detections in one spot
        
        y= smooth(dev_pos(2,:)',100,'rlowess');
        % Positive-slope zero-crossing detector
        z = xor((y > 0), circshift((y > 0), 1)); z(1) = 0;
        % Find the locations of the zero-crossing points
        extrema1{it} = find(z);
        
        
        figure(fig);
        plot(pos(1,extrema1{it}),pos(2,extrema1{it}),'dm','markersize',5,'linewidth',5)
        
        pos=flipDim(demos{it}(1:2,:),1);
   
        % approximate derivatives
        dev_pos= diff(pos,1,2);
        % smooth data to prevent multiple detections in one spot
        y= smooth(dev_pos(2,:)',100,'rlowess');
        % Positive-slope zero-crossing detector
        z = xor((y > 0), circshift((y > 0), 1)); z(1) = 0;
        % Find the locations of the zero-crossing points
        extrema2{it} = find(z);
        plot(demos{it}(1,extrema2{it}),demos{it}(2,extrema2{it}),'dm','markersize',5,'linewidth',5)
        extrema{it}= sort([extrema2{it}; extrema1{it}]);
    end
    
else
    error('only one trajectory nothing to compare to')
end
end