function  [crossing_points fig]= detectInflectionPoints(demos,fig)
%DETECTINFLECTIONPOINTS  detect inflection points in a descrete trajectorie
%   DETECTINFLECTIONPOINTS(demos, fig) returns
%
%   OUTPUT:
%       - CROSSING_POINTS same size as demos and gives in each cell a
%       vector of the indeces indicating the inflection points in the trajectorie.
%   INPUT:
%       - DEMOS cell array of set s of 2D trajectories (demos{i}(1:2,:))
%       - FIG if fig is not an argument of the function a new figure will
%       be created to show the inflection points.

color={'b+', 'k+', 'r+', 'g+','y+','m+'};
if ~exist('fig','var') || isempty(fig)
    fig= figure; box on; hold on; grid on;
    xlabel('x (mm)');
    ylabel('y (mm)');
    for it=1:length(demos)
        
        pos=demos{it}(1:2,:)';
        plot(pos(:,1),pos(:,2),color{it})
    end
end
crossing_points=cell(size(demos));
if length(demos)>1
    for it=1:length(demos)
        
        pos=demos{it}(1:2,:)';
        figure(fig);
        % approximate signed curvature
        dev_pos1= diff(pos,1,1);
        dev_pos2= [diff(pos,2,1); [0 0]];
        curvature = (dev_pos1(:,1).*dev_pos2(:,2)- dev_pos1(:,2).*dev_pos2(:,1))./ ...
            (((dev_pos1(:,1).^2)+(dev_pos1(:,2).^2)).^(3/2));
        % smooth data to prevent multiple detections in one spot
        y=smooth(curvature,50,'rlowess');   
   
        % Positive-negative-slope zero-crossing detector
        z = xor((y > 0), circshift((y > 0), 1)); z(1) = 0;
        % Find the locations of the zero-crossing points
        crossing_points{it} = find(z);
        
        plot(pos(crossing_points{it},1),pos(crossing_points{it},2),'og','markersize',5,'linewidth',5)
    end
    
else
    error('only one trajectory nothing to compare to')
end
end